@@ -176,13 +176,18 @@ class MaterialsBuilder(Builder):
             "task_id",
             "formula_pretty",
             "output.energy_per_atom",
-            "output.energy",
             "output.structure",
+            "input.parameters",
+            # needed for run_type and task_type
             "calcs_reversed.input.parameters",
+            "calcs_reversed.input.incar",
+            "orig_inputs",
+            # needed for entry from task_doc
+            "output.energy",
             "input.is_hubbard",
             "input.hubbards",
             "input.potcar_spec",
-            "orig_inputs",
+            # misc info for materials doc
             "input.structure",
             "tags",
         ]
@@ -225,6 +230,8 @@ class MaterialsBuilder(Builder):
                     f"No valid ids found among ids {failed_ids}. This can be the case if the required "
                     "calculation types are missing from your tasks database."
                 )
+                materials.append(MaterialsDoc.construct_deprecated_material(tasks))
+
         self.logger.debug(f"Produced {len(materials)} materials for {formula}")
 
         return jsanitize([mat.dict() for mat in materials], allow_bson=True)
